@@ -857,6 +857,29 @@ class Sf:
         
         return results
     
+    
+    async def permissionable_fields_bulk_check(self, object_list):
+        permissionable_fields = {}
+        nonpermissionable_fields = {}
+        async_permissionable_fields =  async_wrap(self.object_describe)
+        
+        task_dict = {}
+        task_result_dict = {}
+        
+        for object_name in object_list:
+            task_dict[object_name] = async_permissionable_fields(object_name)
+            
+        task_results = await asyncio.gather(*task_dict.values())
+        
+        for object_name, task_result in zip(task_dict.keys(), task_results):
+            task_result_dict[object_name] = task_result
+        
+        
+        for object in object_list:
+            permissionable_fields[object] = task_result_dict[object]['fields'].T[task_result_dict[object]['fields'].T['permissionable'] == True].index.tolist()
+            nonpermissionable_fields[object] = task_result_dict[object]['fields'].T[task_result_dict[object]['fields'].T['permissionable'] == False].index.tolist()
+        return permissionable_fields, nonpermissionable_fields
+    
     ### ----------------------------------------------------------------------------------------------------
     ### Synchronous Metadata Functions
     ### ----------------------------------------------------------------------------------------------------
